#! /bin/sh

_count()
{
    set -- "$@"
    _COUNT=$#
}

count()
{
    _count "$@" && printf "%s\n" "$_COUNT"
}

die() {
    result=$1
    shift
    echo ": $*" >&2
    exit $result
}

_filename()
{
    case "$1" in
        */*)
            oldIFS=$IFS
            IFS=/
            set -- $1
            IFS=$oldIFS
            while [ $# -gt 9 ]
            do
              shift 9
            done
            eval "_FILENAME=\$$#"
            ;;
        *) _FILENAME=$1
            ;;
    esac
}

filename()
{
    _filename "$@" && printf "%s\n" "$_FILENAME"
}

cmdpath()
{
    _filename "$1"
    _CMD=$_FILENAME
    oldIFS=$IFS
    IFS=:
    set -- $PATH
    IFS=$oldIFS
    cmd=
    for _DIR
    do
      if [ -x "$_DIR/$_CMD" ]
      then
        cmd="$cmd "$_DIR/$_CMD
      fi
    done
}

echoset()
{
    case `echo " \c"` in
        *\\c) _BSC=
              _DN=-n
              ;;
        *)  _BSC="\c"
            _DN=
           ;;
    esac
}

prompt()
{
    [ -n "$_DN$_BSC" ] || echoset
    echo $_DN "${TAB}$*: ${_BSC}"
}

_bashv()
{
    oldIFS=$IFS
    IFS=.
    set -- `echo 'echo $BASH_VERSION' | ${1:-$SHELL}`
    IFS=$oldIFS
    _BASHV=${1:-0}
}

bashv()
{
    _bashv "$@" && printf "%s\n" "$_BASHV"
}

selectshell()
{
    shells="bash bash1 bash2 bash3 ash ksh ksh88 ksh93 pdksh dash"
    echo  "${NL}$eq_bar${NL}"
    echo "${TAB}The following shells should be POSIX compliant."
    echo "${TAB}Please select one.${NL}"

    shift $#
    for shell in $shells
    do
      cmdpath "$shell"
      if [ -n "$cmd" ]
      then
        for s in $cmd
        do
          _bashv $s
          if [ "$_BASHV" -gt "${_BASHVERSION:-0}" ]
          then
            _BASHVERSION=$_BASHV
            _BASH=$s
          fi
          set -- ${1+"$@"} $s
          case $# in ?) n=\ $# ;; *) n=$# ;; esac  ## pad number to 2 digits
          echo "${TAB}$n.  $s"
        done
      fi
    done
    set -- ${1+"$@"} ""
    echo "${TAB}$#.  OTHER${NL}${NL}$eq_bar${NL}"
    while :
    do
      prompt "Select from 1 to $#"
      read s
      case $s in
          *[!0-9]*) continue ;;
          "") exit 5 ;;
          $#) prompt "Enter the full path to your POSIX shell"
              read s
              [ -x "$s" ] && SELECTSHELL=$s || continue
              break
              ;;
          *) [ "$s" -gt "$#" ] && continue
             set -- x "$@"
             shift $s
             eval "SELECTSHELL=\$1"
             break
          ;;
      esac
    done
    _BASH=$_BASH SELECTSHELL=$SELECTSHELL $SELECTSHELL ./install.sh
    exit
}

eq_bar==========================================================================
NL='
'
TAB="	"

echo SELECTSHELL=$SELECTSHELL _BASH=$_BASH
[ -n "$SELECTSHELL" ] || selectshell

configfile=$HOME/.config/script-setup.cfg ## Configuration file

[ -f "$configfile" ] ||
  if [ -x "./Chapter20/script-setup-sh" ]
  then
    ./Chapter20/script-setup-sh || exit 5
  fi

. "$configfile" || die 5 "$configfile not found"

bar=
printf "\n\n\n"
printf "%s\n" "$eq_bar" "Installing scripts"
